##############################################################################
#
# Copyright (c) 2012 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import sys

PY3 = sys.version_info[0] >= 3

if PY3: #pragma NO COVER
    from pickle import Pickler
    from pickle import Unpickler

    def _get_pid(pickler, oid):
        return pickler.memo.copy()[oid][0] #stupid proxy

    def _get_obj(unpickler, pid):
        return unpickler.memo.copy()[pid]

else: #pragma NO COVER
    from cPickle import Pickler
    from cPickle import Unpickler

    def _get_pid(pickler, oid):
        return pickler.memo[oid][0]

    def _get_obj(unpickler, pid):
        return unpickler.memo[pid]

def _apply(func, args=(), kw=None): # 'apply' is missing in Py3k
    if kw is None:
        kw = {}
    return func(*args, **kw)



##############################################################################
#
# Copyright (c) 2012 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
""" Make example classes available at module scope.
"""
import zope.location.location

from zope.copy._compat import _apply

class Demo(object): #pragma NO COVER

    _frozen = None

    def isFrozen(self):
        return self._frozen is not None

    def freeze(self):
        self._frozen = Data()


class Data(object): #pragma NO COVER
    pass


class Subobject(zope.location.location.Location): #pragma NO COVER

    def __init__(self):
        self.counter = 0

    def __call__(self):
        res = self.counter
        self.counter += 1
        return res


class Something(object): #pragma NO COVER
    pass


root = object()


class Other(object): #pragma NO COVER
    @_apply
    def __name__():
        def fget(self):
            return 'something'
        def fset(self, value):
            raise AttributeError
        return property(fget, fset)
    @_apply
    def __parent__():
        def fget(self):
            return root
        def fset(self, value):
            raise AttributeError
        return property(fget, fset)



##############################################################################
#
# Copyright (c) 2009 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Setup for zope.copy package
"""
import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

TESTS_REQUIRE = [
    'zope.location',
    'zope.testing',
]

setup(name = 'zope.copy',
      version = '4.0.2',
      author='Zope Foundation and Contributors',
      author_email='zope-dev@zope.org',
      description='Pluggable object copying mechanism',
      long_description=(
          read('README.rst')
          + '\n\n' +
          read('CHANGES.rst')
          ),
      keywords = "zope3 copying cloning",
      classifiers = [
          'Development Status :: 5 - Production/Stable',
          'Framework :: Zope3',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: Zope Public License',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.2',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy',
          'Topic :: Database',
          ],
      url='http://pypi.python.org/pypi/zope.copy',
      license='ZPL 2.1',
      packages=find_packages('src'),
      package_dir = {'': 'src'},
      namespace_packages=['zope'],
      install_requires = ['setuptools',
                          'zope.interface',
                          ],
      include_package_data = True,
      zip_safe = False,
      test_suite='zope.copy.tests',
      extras_require={
        'test': TESTS_REQUIRE,
        'testing': TESTS_REQUIRE + ['nose', 'coverage'],
        'docs': ['Sphinx', 'repoze.sphinx.autointerface'],
      },
)
